@@ -6,6 +6,7 @@
 #include <kpushbutton.h>
 #include <kstatusbar.h>
 #include <kstdguiitem.h>
+#include <tqapplication.h>
 #include <tqdialog.h>
 #include <tqhbox.h>
 #include <tqlabel.h>
@@ -69,7 +70,16 @@ public:
          , m_title( TheStream::prettyTitle() )
    {
       (new TQVBoxLayout( this ))->setAutoAdd( true );
-      (new TQLabel( this ))->setPixmap( frame );
+
+      // Scale the image to fit within the current screen's size.
+      TQRect screenRect = tqApp->desktop()->availableGeometry( this );
+      if ( screenRect.contains( frame.rect() ) ) {
+         (new TQLabel( this ))->setPixmap( frame );
+      } else {
+         TQSize scaledSize = screenRect.size() * 0.9;
+         TQImage scaledImage = frame.scale( scaledSize, TQImage::ScaleMin );
+         (new TQLabel( this ))->setPixmap( scaledImage );
+      }
 
       TQHBox *box = new TQHBox( this );
       KPushButton *o = new KPushButton( KStdGuiItem::save(), box );
@@ -241,28 +251,34 @@ VideoWindow::captureFrame() const
    DEBUG_BLOCK
 
    int ratio, format, w, h;
-   if( !xine_get_current_frame( *engine(), &w, &h, &ratio, &format, NULL ) )
+   if (!xine_get_current_frame_s(*engine(), &w, &h, &ratio, &format, nullptr, nullptr))
       return TQImage();
 
-   uint8_t *yuv = new uint8_t[((w+8) * (h+1) * 2)];
-   if( yuv == 0 ) {
+   int yuv_size = ((w + 8) * (h + 1)) * 2;
+   uint8_t *yuv = new(std::nothrow) uint8_t[yuv_size];
+   if (yuv == nullptr) {
       Debug::error() << "Not enough memory to make screenframe!\n";
-      return TQImage(); }
+      return TQImage();
+   }
 
-   xine_get_current_frame( *engine(), &w, &h, &ratio, &format, yuv );
+   xine_get_current_frame_s(*engine(), &w, &h, &ratio, &format, yuv, &yuv_size);
 
    // convert to yv12 if necessary
-   uint8_t *y = 0, *u = 0, *v = 0;
+   uint8_t *y = nullptr;
+   uint8_t *u = nullptr;
+   uint8_t *v = nullptr;
+
    switch( format )
    {
    case XINE_IMGFMT_YUY2: {
       uint8_t *yuy2 = yuv;
 
-      yuv = new uint8_t[(w * h * 2)];
-      if( yuv == 0 ) {
+      yuv = new(std::nothrow) uint8_t[(w * h * 2)];
+      if (yuv == nullptr) {
          Debug::error() << "Not enough memory to make screenframe!\n";
          delete [] yuy2;
-         return TQImage(); }
+         return TQImage();
+      }
 
       y = yuv;
       u = yuv + w * h;
@@ -287,7 +303,7 @@ VideoWindow::captureFrame() const
 
    // convert to rgb
    uchar *rgb = yv12ToRgb( y, u, v, w, h );
-   TQImage frame( rgb, w, h, 32, 0, 0, TQImage::IgnoreEndian );
+   TQImage frame( rgb, w, h, 32, nullptr, 0, TQImage::IgnoreEndian );
    delete [] yuv;
 
    return frame;
