@@ -22,11 +22,13 @@
 #include <tqlayout.h>     //ctor
 #include <tqpopupmenu.h>  //because XMLGUI is poorly designed
 #include <tqobjectlist.h>
+#include <tqwidgetstack.h>
 
 #include "../debug.h"
 #include "../mxcl.library.h"
 #include "actions.h"
 #include "analyzer.h"
+#include "audioView.h"
 #include "codeineConfig.h"
 #include "extern.h"       //dialog creation function definitions
 #include "fullScreenAction.h"
@@ -70,8 +72,19 @@ MainWindow::MainWindow()
 
    kapp->setMainWidget( this );
 
+   m_widgetStack = new TQWidgetStack(this, "m_widgetStack");
+
    new VideoWindow( this );
-   setCentralWidget( videoWindow() );
+
+   m_audioView = new AudioView(this, "m_audioView");
+
+   // videoWindow() will be the initial widget.
+   // m_audioView is raised when no video track is present.
+   m_widgetStack->addWidget(videoWindow());
+   m_widgetStack->addWidget(m_audioView);
+
+   setCentralWidget(m_widgetStack);
+
    setFocusProxy( videoWindow() ); // essential! See VideoWindow::event(), TQEvent::FocusOut
 
    // these have no affect beccause "KDE Knows Best" FFS
@@ -523,7 +536,6 @@ show_toolbar:
          //we aren't managed by mainWindow when at FullScreen
          videoWindow()->move( 0, 0 );
          videoWindow()->resize( ((TQWidget*)o)->size() );
-         videoWindow()->lower();
       }
 
       if (o == m_toolbar)
@@ -580,14 +592,12 @@ MainWindow::fullScreenToggled( bool isFullScreen )
    statusBar()->setHidden( isFullScreen );
 
    setMouseTracking( isFullScreen ); /// @see mouseMoveEvent()
+   m_widgetStack->setMouseTracking(isFullScreen);
 
    if (isFullScreen)
       s_handler = new FullScreenToolBarHandler( this );
    else
       delete s_handler;
-
-   // prevent videoWindow() moving around when mouse moves
-   setCentralWidget( isFullScreen ? nullptr : videoWindow() );
 }
 
 void
