@@ -139,9 +139,12 @@ VideoWindow::contextMenuEvent( TQContextMenuEvent *e )
 
    popup.insertSeparator();
 
-   if( TheStream::url().protocol() == "dvd" )
-      action( "toggle_dvd_menu" )->plug( &popup ),
+   if (TheStream::url().protocol() == "dvd")
+   {
+      action("toggle_dvd_menu")->plug(&popup);
       popup.insertSeparator();
+   }
+
    if( !((TDEToggleAction*)actionCollection()->action( "fullscreen" ))->isChecked() )
       action( "reset_zoom" )->plug( &popup );
    action( "capture_frame" )->plug( &popup );
@@ -223,11 +226,6 @@ VideoWindow::event( TQEvent *e )
          stop();
          return false;
 
-      case VideoWindow::ExposeEvent:
-         //see VideoWindow::x11Event()
-
-         return true;
-
       // Xlib.h sucks fucking balls!!!!11!!1!
       #undef KeyPress
       case TQEvent::KeyPress: {
@@ -259,7 +257,7 @@ VideoWindow::event( TQEvent *e )
             xine_event_t xineEvent;
 
             xineEvent.type = keyCode;
-            xineEvent.data = NULL;
+            xineEvent.data = nullptr;
             xineEvent.data_length = 0;
 
             xine_event_send( m_stream, &xineEvent );
