@@ -18,7 +18,7 @@
 namespace Codeine {
 
 
-VideoWindow *VideoWindow::s_instance = 0;
+VideoWindow *VideoWindow::s_instance = nullptr;
 
 
 namespace X
@@ -30,12 +30,12 @@ namespace X
 
 VideoWindow::VideoWindow( TQWidget *parent, const char *name )
       : TQWidget( parent, name )
-      , m_osd( 0 )
-      , m_stream( 0 )
-      , m_eventQueue( 0 )
-      , m_videoPort( 0 )
-      , m_audioPort( 0 )
-      , m_xine( 0 )
+      , m_osd( nullptr )
+      , m_stream( nullptr )
+      , m_eventQueue( nullptr )
+      , m_videoPort( nullptr )
+      , m_audioPort( nullptr )
+      , m_xine( nullptr )
       , m_displayRatio( 1 )
 {
    s_instance = this;
